@@ -1,11 +1,13 @@
 from django.db import models
+from django.utils.encoding import python_2_unicode_compatible
 
 
+@python_2_unicode_compatible
 class TinyContent(models.Model):
     name = models.CharField(max_length=100, unique=True)
     content = models.TextField()
 
-    def __unicode__(self):
+    def __str__(self):
         return self.name
 
     class Meta:
